@@ -12,15 +12,14 @@
 # serve to show the default value.
 
 
-from io import open
 import os
 
-base_path = os.path.dirname(__file__)
+from traitsui import __version__ as version
 
 # If your extensions are in another directory, add it here. If the directory
 # is relative to the documentation root, use os.path.abspath to make it
 # absolute, like shown here.
-#sys.path.append(os.path.abspath('some/directory'))
+# sys.path.append(os.path.abspath('some/directory'))
 
 # General configuration
 # ---------------------
@@ -34,6 +33,7 @@ extensions = [
     'sphinx.ext.napoleon',
     # Link to code in sphinx generated API docs
     "sphinx.ext.viewcode",
+    "sphinx_copybutton",
     'traits.util.trait_documenter',
 ]
 
@@ -48,58 +48,44 @@ master_doc = 'index'
 
 # General substitutions.
 project = 'traitsui'
-copyright = '2008-2020, Enthought'
-
-# The default replacements for |version| and |release|, also used in various
-# other places throughout the built documents.
-#
-# Pull from the actual release number without imports
-d = {}
-try:
-    version_path = os.path.join(base_path, '..', '..', 'traitsui', '_version.py')
-    with open(version_path, 'r', encoding='utf8') as fp:
-        exec(compile(fp.read(), version_path, 'exec'), d)
-    release = d['version']
-    version = '.'.join(d['version'].split('.', 2)[:2])
-
-except IOError as ioe:
-    import warnings
-    msg = '''_version.py seems to be missing!
-            Please run
-            $ python setup.py develop
-            to generate this file!'''
-    warnings.warn(RuntimeWarning(msg.format(ioe)))
+copyright = '2008-2023, Enthought'
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
-#today = ''
+# today = ''
 # Else, today_fmt is used as the format for a strftime call.
 today_fmt = '%B %d, %Y'
 
 # List of documents that shouldn't be included in the build.
-#unused_docs = []
+# unused_docs = []
 
 # List of directories, relative to source directories, that shouldn't be searched
 # for source files.
-#exclude_dirs = []
+# exclude_dirs = []
 
 # The reST default role (used for this markup: `text`) to use for all documents.
-#default_role = None
+# default_role = None
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
-#add_function_parentheses = True
+# add_function_parentheses = True
 
 # If true, the current module name will be prepended to all description
 # unit titles (such as .. function::).
-#add_module_names = True
+# add_module_names = True
 
 # If true, sectionauthor and moduleauthor directives will be shown in the
 # output. They are ignored by default.
-#show_authors = False
+# show_authors = False
 
 # The name of the Pygments (syntax highlighting) style to use.
 pygments_style = 'sphinx'
 
+# Options for Sphinx copybutton extension
+# ---------------------------------------
+
+# Matches prompts - "$ ", ">>>" and "..."
+copybutton_prompt_text = r">>> |\.\.\. |\$ "
+copybutton_prompt_is_regexp = True
 
 # Options for HTML output
 # -----------------------
@@ -107,29 +93,28 @@ pygments_style = 'sphinx'
 # The style sheet to use for HTML and HTML Help pages. A file of that name
 # must exist either in Sphinx' static/ path, or in one of the custom paths
 # given in html_static_path.
-#html_style = 'default.css'
+# html_style = 'default.css'
 
 # The name for this set of Sphinx documents.  If None, it defaults to
 # "<project> v<release> documentation".
 html_title = "TraitsUI {} Documentation".format(version.split('.')[0])
 
 # A shorter title for the navigation bar.  Default is the same as html_title.
-#html_short_title = None
+# html_short_title = None
 
 # The name of an image file (within the static path) to place at the top of
 # the sidebar.
-#html_logo = "e-logo-rev.png"
+# html_logo = "e-logo-rev.png"
 
 # The name of an image file (within the static path) to use as favicon of the
 # docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
 # pixels large.
-#html_favicon = "favicon.ico"
+# html_favicon = "favicon.ico"
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static',
-                    os.path.join('tutorials', 'code_snippets')]
+html_static_path = ['_static', os.path.join('tutorials', 'code_snippets')]
 
 # If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
 # using the given strftime format.
@@ -140,31 +125,31 @@ html_last_updated_fmt = '%b %d, %Y'
 html_use_smartypants = True
 
 # Custom sidebar templates, maps document names to template names.
-#html_sidebars = {}
+# html_sidebars = {}
 
 # Additional templates that should be rendered to pages, maps page names to
 # template names.
-#html_additional_pages = {}
+# html_additional_pages = {}
 
 # If false, no module index is generated.
 html_use_modindex = False
 
 # If false, no index is generated.
-#html_use_index = False
+# html_use_index = False
 
 # If true, the index is split into individual pages for each letter.
-#html_split_index = False
+# html_split_index = False
 
 # If true, the reST sources are included in the HTML build as _sources/<name>.
-#html_copy_source = True
+# html_copy_source = True
 
 # If true, an OpenSearch description file will be output, and all pages will
 # contain a <link> tag referring to it.  The value of this option must be the
 # base URL from which the finished HTML is served.
-#html_use_opensearch = ''
+# html_use_opensearch = ''
 
 # If nonempty, this is the file name suffix for HTML files (e.g. ".xhtml").
-#html_file_suffix = ''
+# html_file_suffix = ''
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = 'Traitsuidoc'
@@ -177,6 +162,7 @@ try:
     html_theme = 'enthought'
 except ImportError as exc:
     import warnings
+
     msg = '''Can't find Enthought Sphinx Theme, using default.
             Exception was: {}
             Enthought Sphinx Theme can be downloaded from
@@ -195,24 +181,32 @@ except ImportError as exc:
 # #html_theme = 'classic'
 
 # Useful aliases to avoid repeating long URLs.
-extlinks = {'github-demo': (
-    'https://github.com/enthought/traitsui/tree/master/traitsui/examples/demo/%s',
-    'github-demo')
+extlinks = {
+    'github-demo': (
+        f'https://github.com/enthought/traitsui/tree/{version}/traitsui/examples/demo/%s',
+        'github-demo',
+    )
 }
 
 # Options for LaTeX output
 # ------------------------
 
 # The paper size ('letter' or 'a4').
-#latex_paper_size = 'letter'
+# latex_paper_size = 'letter'
 
 # The font size ('10pt', '11pt' or '12pt').
-#latex_font_size = '10pt'
+# latex_font_size = '10pt'
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, document class [howto/manual]).
 latex_documents = [
-  ('index', 'TraitsUI.tex', 'TraitsUI 4 User Manual', 'Enthought, Inc.', 'manual'),
+    (
+        'index',
+        'TraitsUI.tex',
+        'TraitsUI 4 User Manual',
+        'Enthought, Inc.',
+        'manual',
+    ),
 ]
 
 # The name of an image file (relative to this directory) to place at the top of
@@ -222,21 +216,18 @@ latex_logo = "e-logo-rev.png"
 
 # For "manual" documents, if this is true, then toplevel headings are parts,
 # not chapters.
-#latex_use_parts = False
+# latex_use_parts = False
 
 # Additional stuff for the LaTeX preamble.
-#latex_preamble = ''
+# latex_preamble = ''
 
 # Documents to append as an appendix to all manuals.
-#latex_appendices = []
+# latex_appendices = []
 
 # If false, no module index is generated.
-#latex_use_modindex = True
+# latex_use_modindex = True
 
 # Autodoc options
-autodo_mock_imports = [
-    "wx", "PySide", "PyQt", "PyQt5"
-]
 
 # Intersphinx configuration
 intersphinx_mapping = {
