@@ -1,13 +1,14 @@
 # echo_box.py
 
-from traits.api import *
+from traits.api import HasTraits, Str
+
 
 class EchoBox(HasTraits):
-    input =  Str()
+    input = Str()
     output = Str()
 
     def _input_changed(self):
         self.output = self.input
 
-EchoBox().configure_traits()
 
+EchoBox().configure_traits()
