@@ -1,10 +1,12 @@
 # event_loop.py
 
-from traits.api import *
+from traits.api import HasTraits, Int
 from pyface.api import GUI
 
+
 class Counter(HasTraits):
-    value =  Int()
+    value = Int()
+
 
 Counter().edit_traits()
 GUI().start_event_loop()
