@@ -1,5 +1,12 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 """
 This example shows how to define a read-only, auto-edit table column using a
@@ -25,41 +32,45 @@ activated on mouse over, rather than the pop-up view specified by the 'view'
 trait.
 """
 
-#-- Imports --------------------------------------------------------------
+# -- Imports --------------------------------------------------------------
 
-from __future__ import absolute_import, division
 
 from operator import attrgetter
 
-from traits.api \
-    import HasTraits, Int, List, Range, Property, property_depends_on
+from traits.api import (
+    HasTraits,
+    Int,
+    List,
+    Range,
+    Property,
+    cached_property,
+)
 
-from traitsui.api \
-    import View, VGroup, Item, TableEditor
+from traitsui.api import View, VGroup, Item, TableEditor
 
-from traitsui.table_column \
-    import ObjectColumn
+from traitsui.table_column import ObjectColumn
 
-#-- Integer Class --------------------------------------------------------
+# -- Integer Class --------------------------------------------------------
 
 
 class Integer(HasTraits):
 
     # The value:
-    n = Int
+    n = Int()
 
-#-- Factor Class ---------------------------------------------------------
+
+# -- Factor Class ---------------------------------------------------------
 
 
 class Factor(HasTraits):
 
     # The number being factored:
-    n = Int
+    n = Int()
 
     # The list of factors of 'n':
-    factors = Property(List)
+    factors = Property(List, observe='n')
 
-    @property_depends_on('n')
+    @cached_property
     def _get_factors(self):
         n = self.n
         i = 1
@@ -77,29 +88,30 @@ class Factor(HasTraits):
 
         return result
 
-#-- The table editor used for the pop-up view ----------------------------
+
+# -- The table editor used for the pop-up view ----------------------------
 
 factor_table_editor = TableEditor(
     columns=[
-        ObjectColumn(name='n',
-                     width=1.0,
-                     editable=False,
-                     horizontal_alignment='center')
+        ObjectColumn(
+            name='n', width=1.0, editable=False, horizontal_alignment='center'
+        )
     ],
     sortable=False,
     auto_size=False,
     show_toolbar=False,
-    show_column_labels=False
+    show_column_labels=False,
 )
 
-#-- The table editor used for the main view ------------------------------
+# -- The table editor used for the main view ------------------------------
 
 factors_view = View(
-    Item('factors',
-         id='factors',
-         show_label=False,
-         editor=factor_table_editor,
-         ),
+    Item(
+        'factors',
+        id='factors',
+        show_label=False,
+        editor=factor_table_editor,
+    ),
     id='traits.examples.demo.Advanced.factors_view',
     kind='info',
     height=0.30,
@@ -107,24 +119,25 @@ factors_view = View(
 
 factors_table_editor = TableEditor(
     columns=[
-        ObjectColumn(name='n',
-                     width=0.5,
-                     editable=False,
-                     horizontal_alignment='center'),
-        ObjectColumn(name='factors',
-                     width=0.5,
-                     editable=False,
-                     horizontal_alignment='center',
-                     auto_editable=True,
-                     format_func=lambda f: '%s factors' % len(f),
-                     view=factors_view),
+        ObjectColumn(
+            name='n', width=0.5, editable=False, horizontal_alignment='center'
+        ),
+        ObjectColumn(
+            name='factors',
+            width=0.5,
+            editable=False,
+            horizontal_alignment='center',
+            auto_editable=True,
+            format_func=lambda f: '%s factors' % len(f),
+            view=factors_view,
+        ),
     ],
     sortable=False,
     auto_size=False,
-    show_toolbar=False
+    show_toolbar=False,
 )
 
-#-- Factors Class --------------------------------------------------------
+# -- Factors Class --------------------------------------------------------
 
 
 class Factors(HasTraits):
@@ -133,7 +146,7 @@ class Factors(HasTraits):
     max_n = Range(1, 1000, 20, mode='slider')
 
     # The list of Factor objects:
-    factors = Property(List)
+    factors = Property(List, observe='max_n')
 
     # The view of the list of Factor objects:
     view = View(
@@ -142,26 +155,24 @@ class Factors(HasTraits):
                 Item('max_n'),
                 show_labels=False,
                 show_border=True,
-                label='Maximum Number'
+                label='Maximum Number',
             ),
             VGroup(
-                Item('factors',
-                     show_label=False,
-                     editor=factors_table_editor
-                     ),
-            )
+                Item('factors', show_label=False, editor=factors_table_editor),
+            ),
         ),
         title='List of numbers and their factors',
         width=0.2,
         height=0.4,
-        resizable=True
+        resizable=True,
     )
 
-    @property_depends_on('max_n')
+    @cached_property
     def _get_factors(self):
         return [Factor(n=i + 1) for i in range(self.max_n)]
 
-#-- Create and run the demo ----------------------------------------------
+
+# -- Create and run the demo ----------------------------------------------
 
 # Create the demo:
 demo = Factors()
