@@ -1,5 +1,12 @@
-#  Copyright (c) 2007, Enthought, Inc.
-#  License: BSD Style.
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 
 """
 Sometimes the inputs to a model are not correlated. That is, any valid model
@@ -57,16 +64,20 @@ that when the kinetic energy drops below 50,000, the fields return to their
 normal color.
 """
 
-#-- Imports --------------------------------------------------------------
+# -- Imports --------------------------------------------------------------
 
-from __future__ import absolute_import
-from traits.api \
-    import HasTraits, Range, Float, Bool, Str, Property, property_depends_on
+from traits.api import (
+    HasTraits,
+    Range,
+    Float,
+    Bool,
+    Str,
+    Property,
+)
 
-from traitsui.api \
-    import View, VGroup, Item
+from traitsui.api import View, VGroup, Item
 
-#-- System Class ---------------------------------------------------------
+# -- System Class ---------------------------------------------------------
 
 
 class System(HasTraits):
@@ -78,54 +89,49 @@ class System(HasTraits):
     velocity = Range(0.0, 100.0)
 
     # The kinetic energy of the system:
-    kinetic_energy = Property(Float)
+    kinetic_energy = Property(Float, observe='mass, velocity')
 
     # The current error status of the system:
     error = Property(
         Bool,
-        sync_to_view='mass.invalid, velocity.invalid, status.invalid')
+        sync_to_view='mass.invalid, velocity.invalid, status.invalid',
+        observe='kinetic_energy',
+    )
 
     # The current status of the system:
-    status = Property(Str)
+    status = Property(Str, observe='error')
 
     view = View(
         VGroup(
             VGroup(
                 Item('mass'),
                 Item('velocity'),
-                Item('kinetic_energy',
-                     style='readonly',
-                     format_str='%.0f'
-                     ),
+                Item('kinetic_energy', style='readonly', format_str='%.0f'),
                 label='System',
-                show_border=True),
+                show_border=True,
+            ),
             VGroup(
-                Item('status',
-                     style='readonly',
-                     show_label=False
-                     ),
+                Item('status', style='readonly', show_label=False),
                 label='Status',
-                show_border=True
+                show_border=True,
             ),
         )
     )
 
-    @property_depends_on('mass, velocity')
     def _get_kinetic_energy(self):
         return (self.mass * self.velocity * self.velocity) / 2.0
 
-    @property_depends_on('kinetic_energy')
     def _get_error(self):
-        return (self.kinetic_energy > 50000.0)
+        return self.kinetic_energy > 50000.0
 
-    @property_depends_on('error')
     def _get_status(self):
         if self.error:
             return 'The kinetic energy of the system is too high.'
 
         return ''
 
-#-- Create and run the demo ----------------------------------------------
+
+# -- Create and run the demo ----------------------------------------------
 
 # Create the demo:
 demo = System()
