@@ -1,3 +1,13 @@
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """
 Dynamic enabling parts of a user interface using 'enabled_when'
 
@@ -19,23 +29,21 @@ attribute of the Person being viewed.
 Compare this to very similar demo of *visible_when*.
 """
 
-from __future__ import absolute_import
 from traits.api import HasTraits, Str, Range, Bool, Enum
 from traitsui.api import Item, Group, View, Label
 
 
 class Person(HasTraits):
-    """ Example of enabling/disabling components of a user interface.
-    """
+    """Example of enabling/disabling components of a user interface."""
 
     # General traits:
-    first_name = Str
-    last_name = Str
+    first_name = Str()
+    last_name = Str()
     age = Range(0, 120)
 
     # Traits for children only:
-    legal_guardian = Str
-    school = Str
+    legal_guardian = Str()
+    school = Str()
     grade = Range(1, 12)
 
     # Traits for adults only:
@@ -49,7 +57,7 @@ class Person(HasTraits):
         Item(name='last_name'),
         Item(name='age'),
         label='General Info',
-        show_border=True
+        show_border=True,
     )
 
     # Interface for attributes of Persons under 18:
@@ -81,19 +89,16 @@ class Person(HasTraits):
             Label("Using 'enabled_when':"),
             '10',
             child_group,
-            adult_group
+            adult_group,
         ),
         title='Personal Information',
         resizable=True,
-        buttons=['OK']
+        buttons=['OK'],
     )
 
+
 # Create the demo:
-demo = Person(
-    first_name="Samuel",
-    last_name="Johnson",
-    age=16
-)
+demo = Person(first_name="Samuel", last_name="Johnson", age=16)
 
 # Run the demo (if invoked from the command line):
 if __name__ == '__main__':
