@@ -1,3 +1,13 @@
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 """
 HTML editor
 
@@ -16,21 +26,24 @@ The HTML editor can optionally be configured to do simple formatting of lists
 and paragraphs without HTML tags, by setting the editor's 'format_text'
 parameter True.
 
+Please refer to the `HTMLEditor API docs`_ for further information.
+
+.. _HTMLEditor API docs: https://docs.enthought.com/traitsui/api/traitsui.editors.html_editor.html#traitsui.editors.html_editor.HTMLEditor
 """
 
-from __future__ import absolute_import
 from traits.api import HasTraits, HTML
 from traitsui.api import UItem, View, HTMLEditor
 
 # Sample text to display as HTML: header, plus module docstring, plus
 # some lists. The docstring and lists will be auto-formatted
 # (format_text=True).
-sample_text = ("""
+sample_text = (
+    """
 <html><body><h1>HTMLEditor example</h1>
 
-""" +
-               __doc__ +
-               """
+"""
+    + __doc__
+    + """
 <i>Here are some lists formatted in this way:</i>
 
 Numbered list:
@@ -42,25 +55,30 @@ Bulleted list:
   - eat
   - drink
   - be merry
-""")
+"""
+)
 
 
 class HTMLEditorDemo(HasTraits):
-    """ Defines the main HTMLEditor demo class. """
+    """Defines the main HTMLEditor demo class."""
 
     # Define a HTML trait to view
     my_html_trait = HTML(sample_text)
 
     # Demo view
     traits_view = View(
-        UItem('my_html_trait',
-              # we specify the editor explicitly in order to set format_text:
-              editor=HTMLEditor(format_text=True)),
+        UItem(
+            'my_html_trait',
+            # we specify the editor explicitly in order to set format_text:
+            editor=HTMLEditor(format_text=True),
+        ),
         title='HTMLEditor',
         buttons=['OK'],
         width=800,
         height=600,
-        resizable=True)
+        resizable=True,
+    )
+
 
 # Create the demo:
 demo = HTMLEditorDemo()
