@@ -1,4 +1,4 @@
-#  Copyright (c) 2007, Enthought, Inc.
+#  (C) Copyright 2007-2023 Enthought, Inc., Austin, TX
 #  License: BSD Style.
 
 # view_multi_object.py --- Example of a view for
@@ -18,15 +18,13 @@ class Company(HasTraits):
 
 
 # Standalone View object referencing objects in the UI context
-employee_view = View('e.first_name', 'e.last_name',
-                     'c.company_name')
+employee_view = View('e.first_name', 'e.last_name', 'c.company_name')
 
 bill = Person(first_name='Bill')
 acme = Company(company_name='Acme Products')
 
 
 class TraitApp(wx.App):
-
     def __init__(self, obj1, obj2, view):
         self.obj1 = obj1
         self.obj2 = obj2
