@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -10,9 +10,6 @@
 
 from datetime import date
 
-from traits.etsconfig.api import ETSConfig
-ETSConfig.toolkit = 'qt4'
-
 from traits.api import Date, Dict, HasTraits, List, observe
 from traitsui.api import View, Item, StyledDateEditor
 from traitsui.editors.styled_date_editor import CellFormat
@@ -33,8 +30,10 @@ class Foo(HasTraits):
             style="custom",
             show_label=False,
             editor=StyledDateEditor(
-                dates_trait="dates",
-                styles_trait="styles")))
+                dates_trait="dates", styles_trait="styles"
+            ),
+        )
+    )
 
     def __init__(self, *args, **kw):
         HasTraits.__init__(self, *args, **kw)
@@ -44,15 +43,15 @@ class Foo(HasTraits):
         }
 
         self.fast_dates = [
-            date(
-                2010, 7, 4), date(
-                2010, 7, 3), date(
-                2010, 7, 2)]
+            date(2010, 7, 4),
+            date(2010, 7, 3),
+            date(2010, 7, 2),
+        ]
         self.slow_dates = [
-            date(
-                2010, 6, 28), date(
-                2010, 6, 27), date(
-                2010, 6, 24)]
+            date(2010, 6, 28),
+            date(2010, 6, 27),
+            date(2010, 6, 24),
+        ]
 
     @observe("fast_dates,slow_dates")
     def _update_dates_dict(self, event):
