@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,8 +8,8 @@
 #
 # Thanks for using Enthought open source!
 
-from traits.api import *
-from traitsui.api import *
+from traits.api import HasTraits, List, Str
+from traitsui.api import EnumEditor, Item, View
 
 
 def evaluate_value(v):
@@ -24,10 +24,10 @@ class Team(HasTraits):
 
     captain_editor = EnumEditor(name='players', evaluate=evaluate_value)
 
-    view = View(Item('captain', editor=captain_editor),
-                '_',
-                'players@',
-                height=200)
+    view = View(
+        Item('captain', editor=captain_editor), '_', 'players@', height=200
+    )
+
 
 if __name__ == '__main__':
     team = Team()
