@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,8 +8,8 @@
 #
 # Thanks for using Enthought open source!
 
-from traits.api import *
-from traitsui.api import *
+from traits.api import HasTraits, List, Str
+from traitsui.api import Item, SetEditor, View
 
 
 class Team(HasTraits):
@@ -17,11 +17,14 @@ class Team(HasTraits):
     batting_order = List(Str)
     roster = List(['Tom', 'Dick', 'Harry', 'Sally'], Str)
 
-    view = View(Item('batting_order', editor=SetEditor(name='roster',
-                                                       ordered=True)),
-                '_', 'roster@',
-                height=500,
-                resizable=True)
+    view = View(
+        Item('batting_order', editor=SetEditor(name='roster', ordered=True)),
+        '_',
+        'roster@',
+        height=500,
+        resizable=True,
+    )
+
 
 if __name__ == '__main__':
     Team().configure_traits()
