@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -19,8 +19,7 @@ from traitsui.toolkit_traits import Color
 
 
 class CodeEditor(EditorFactory):
-    """ Editor factory for code editors.
-    """
+    """Editor factory for code editors."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
