@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,8 +15,7 @@ from traitsui.editors.file_editor import FileEditor
 
 
 class DirectoryEditor(FileEditor):
-    """ Editor factory for directory editors.
-    """
+    """Editor factory for directory editors."""
 
     pass
 
