@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -20,8 +20,7 @@ from traitsui.editor_factory import EditorFactory
 
 
 class DNDEditor(EditorFactory):
-    """ Editor factory for drag-and-drop editors.
-    """
+    """Editor factory for drag-and-drop editors."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
