@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -14,8 +14,7 @@ from traitsui.editors.date_editor import DateEditor
 
 
 class StyledDateEditor(DateEditor):
-    """ A DateEditor that can show sets of dates in different styles.
-    """
+    """A DateEditor that can show sets of dates in different styles."""
 
     #: The name of a dictionary on the object that maps names to groups
     #: (list/tuples) of datetime.date objects.  Each of these groups can be
