@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -18,8 +18,7 @@ from traitsui.ui_traits import AView
 
 
 class TimeEditor(EditorFactory):
-    """ Editor factory for time editors.
-    """
+    """Editor factory for time editors."""
 
     # -------------------------------------------------------------------------
     #  Trait definitions:
