@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -12,39 +12,36 @@
 """
 
 
-
 from traits.etsconfig.api import ETSConfig
 
 from ..table_column import ObjectColumn
 
 if ETSConfig.toolkit == "wx":
     from pyface.ui.wx.grid.checkbox_renderer import CheckboxRenderer
-elif ETSConfig.toolkit == "qt4":
-    from ..qt4.extra.checkbox_renderer import CheckboxRenderer
+elif ETSConfig.toolkit in {"qt", "qt4"}:
+    from ..qt.extra.checkbox_renderer import CheckboxRenderer
 else:
     raise NotImplementedError("No checkbox renderer for backend")
 
 
 class CheckboxColumn(ObjectColumn):
     def __init__(self, **traits):
-        """ Initializes the object.
-        """
+        """Initializes the object."""
         super().__init__(**traits)
 
         # force the renderer to be a checkbox renderer
         self.renderer = CheckboxRenderer()
 
     def get_cell_color(self, object):
-        """ Returns the cell background color for the column for a specified
-            object.
+        """Returns the cell background color for the column for a specified
+        object.
         """
 
         # Override the parent class to ALWAYS provide the standard color:
         return self.cell_color_
 
     def is_editable(self, object):
-        """ Returns whether the column is editable for a specified object.
-        """
+        """Returns whether the column is editable for a specified object."""
 
         # Although a checkbox column is always editable, we return this
         # to keep a standard editor from appearing. The editing is handled
