@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -15,7 +15,7 @@ from traitsui.testing.tester._ui_tester_registry.wx import _interaction_helpers
 
 
 def register(registry):
-    """ Register solvers/handlers specific to wx Button Editors
+    """Register solvers/handlers specific to wx Button Editors
     for the given registry.
 
     If there are any conflicts, an error will occur.
@@ -28,12 +28,15 @@ def register(registry):
     registry.register_interaction(
         target_class=ButtonEditor,
         interaction_class=MouseClick,
-        handler=(lambda wrapper, _: _interaction_helpers.mouse_click_button(
-                 control=wrapper._target.control, delay=wrapper.delay))
+        handler=(
+            lambda wrapper, _: _interaction_helpers.mouse_click_button(
+                control=wrapper._target.control, delay=wrapper.delay
+            )
+        ),
     )
 
     registry.register_interaction(
         target_class=ButtonEditor,
         interaction_class=DisplayedText,
-        handler=lambda wrapper, _: wrapper._target.control.GetLabel()
+        handler=lambda wrapper, _: wrapper._target.control.GetLabel(),
     )
