@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -57,8 +57,7 @@ class TestCodeEditor(BaseTestMixin, unittest.TestCase):
 
     @requires_toolkit([ToolkitName.qt])
     def test_code_editor_show_line_numbers(self):
-        """ CodeEditor should honor the `show_line_numbers` setting
-        """
+        """CodeEditor should honor the `show_line_numbers` setting"""
 
         def is_line_numbers_visible(ui):
             from pyface import qt
@@ -78,8 +77,7 @@ class TestCodeEditor(BaseTestMixin, unittest.TestCase):
 
     @requires_toolkit([ToolkitName.qt])
     def test_code_editor_readonly(self):
-        """ Test readonly editor style for CodeEditor
-        """
+        """Test readonly editor style for CodeEditor"""
         from pyface import qt
 
         code_model = CodeModel()
