@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -68,14 +68,13 @@ def multi_select_selected_color_view():
 
 @requires_toolkit([ToolkitName.qt])
 class TestDateEditorCustomQt(BaseTestMixin, unittest.TestCase):
-
     def setUp(self):
         BaseTestMixin.setUp(self)
 
     def tearDown(self):
         BaseTestMixin.tearDown(self)
 
-    def test_single_select_qt4(self):
+    def test_single_select_qt(self):
         with self.launch_editor(single_select_custom_view) as (foo, editor):
             date = datetime.date(2018, 2, 3)
             self.click_date_on_editor(editor, date)
@@ -94,7 +93,7 @@ class TestDateEditorCustomQt(BaseTestMixin, unittest.TestCase):
 
             self.assertEqual(foo.dates, sorted(dates))
 
-    def test_multi_select_qt4_styles_reset(self):
+    def test_multi_select_qt_styles_reset(self):
         with self.launch_editor(multi_select_custom_view) as (foo, editor):
             date = datetime.date(2018, 2, 1)
             self.click_date_on_editor(editor, date)
@@ -103,7 +102,7 @@ class TestDateEditorCustomQt(BaseTestMixin, unittest.TestCase):
             self.click_date_on_editor(editor, date)
             self.check_select_status(editor=editor, date=date, selected=False)
 
-    def test_multi_select_qt4_set_model_dates(self):
+    def test_multi_select_qt_set_model_dates(self):
         # Test setting the dates from the model object.
         with self.launch_editor(multi_select_custom_view) as (foo, editor):
             foo.dates = [datetime.date(2010, 1, 2), datetime.date(2010, 2, 1)]
@@ -129,7 +128,7 @@ class TestDateEditorCustomQt(BaseTestMixin, unittest.TestCase):
     def launch_editor(self, view_factory):
         foo = Foo()
         with create_ui(foo, dict(view=view_factory())) as ui:
-            editor, = ui._editors
+            (editor,) = ui._editors
             yield foo, editor
 
     def check_select_status(self, editor, date, selected):
@@ -140,19 +139,19 @@ class TestDateEditorCustomQt(BaseTestMixin, unittest.TestCase):
         if selected:
             self.assertEqual(
                 textformat.fontWeight(),
-                QtGui.QFont.Bold,
+                QtGui.QFont.Weight.Bold,
                 "{!r} is not selected.".format(date),
             )
             self.check_date_bgcolor(editor, date, (0, 128, 0))
         else:
             self.assertEqual(
                 textformat.fontWeight(),
-                QtGui.QFont.Normal,
+                QtGui.QFont.Weight.Normal,
                 "{!r} is not unselected.".format(date),
             )
             self.assertEqual(
                 textformat.background().style(),
-                0,  # Qt.BrushStyle.NoBrush,
+                QtCore.Qt.BrushStyle.NoBrush,
                 "Expected brush to have been reset.",
             )
             self.check_date_bgcolor(editor, date, (0, 0, 0))
@@ -183,11 +182,10 @@ class TestDateEditorCustomQt(BaseTestMixin, unittest.TestCase):
 # Run this test case against wx too once enthought/traitsui#752 is fixed.
 @requires_toolkit([ToolkitName.qt])
 class TestDateEditorInitDispose(unittest.TestCase):
-    """ Test the init and dispose of date editor."""
+    """Test the init and dispose of date editor."""
 
     def check_init_and_dispose(self, view):
-        with reraise_exceptions(), \
-                create_ui(Foo(), dict(view=view)):
+        with reraise_exceptions(), create_ui(Foo(), dict(view=view)):
             pass
 
     def test_simple_date_editor(self):
