@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,6 +11,8 @@
 """ General regression tests for various fixed bugs.
 """
 
+from subprocess import check_output, STDOUT
+import sys
 import unittest
 
 from traits.api import DelegatesTo, Event, HasTraits, Instance, Undefined
@@ -31,7 +33,6 @@ class Child(HasTraits):
 
 
 class TestRegression(BaseTestMixin, unittest.TestCase):
-
     def setUp(self):
         BaseTestMixin.setUp(self)
 
@@ -39,8 +40,7 @@ class TestRegression(BaseTestMixin, unittest.TestCase):
         BaseTestMixin.tearDown(self)
 
     def test_editor_on_delegates_to_event(self):
-        """ Make sure that DelegatesTo on Events passes Editor creation.
-        """
+        """Make sure that DelegatesTo on Events passes Editor creation."""
         child = Child(parent=Parent())
         editor = Editor(
             None, factory=TextEditor(), object=child, name="button"
@@ -48,8 +48,7 @@ class TestRegression(BaseTestMixin, unittest.TestCase):
         self.assertIs(editor.old_value, Undefined)
 
     def test_attribute_error(self):
-        """ Make sure genuine AttributeErrors raise on Editor creation.
-        """
+        """Make sure genuine AttributeErrors raise on Editor creation."""
         self.assertRaises(
             AttributeError,
             Editor,
@@ -58,3 +57,13 @@ class TestRegression(BaseTestMixin, unittest.TestCase):
             object=Parent(),
             name="not_a_trait",
         )
+
+    def test_importing_view_does_not_import_toolkit(self):
+        output = check_output(
+            [sys.executable, "-c",
+             "import sys; from traitsui.view import View;"
+             "print(list(sys.modules.keys()))"],
+            stderr=STDOUT
+        )
+        output = output.decode('ascii')
+        self.assertFalse('QtCore' in output)
