@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -43,7 +43,6 @@ class SimpleExample(HasTraits):
 
 
 class DummyCommand(AbstractCommand):
-
     def do(self):
         self.data = "do"
 
@@ -55,7 +54,6 @@ class DummyCommand(AbstractCommand):
 
 
 class LegacyUndoItem(AbstractUndoItem):
-
     def undo(self):
         pass
 
@@ -63,23 +61,7 @@ class LegacyUndoItem(AbstractUndoItem):
         pass
 
 
-class TestAbstractUndoItem(UnittestTools, unittest.TestCase):
-
-    def test_merge_undo_deprecated(self):
-        undo_item = LegacyUndoItem()
-        other_item = LegacyUndoItem()
-
-        with catch_warnings(record=True) as w:
-            result = undo_item.merge(other_item)
-            self.assertEqual(len(w), 1)
-            self.assertTrue(issubclass(w[0].category, DeprecationWarning))
-            self.assertIn("merge_undo", str(w[0].message))
-
-        self.assertFalse(result)
-
-
 class TestUndoItem(UnittestTools, unittest.TestCase):
-
     def test_undo(self):
         example = SimpleExample(value=11)
 
@@ -487,7 +469,6 @@ class TestUndoItem(UnittestTools, unittest.TestCase):
 
 
 class TestListUndoItem(UnittestTools, unittest.TestCase):
-
     def test_undo(self):
         example = SimpleExample(list_value=['foo', 'wombat', 'baz'])
 
@@ -553,7 +534,7 @@ class TestListUndoItem(UnittestTools, unittest.TestCase):
             name='list_value',
             index=1,
             added=[['wombat'], 'baz'],
-            removed=removed.copy()
+            removed=removed.copy(),
         )
         next_undo_item = ListUndoItem(
             object=example,
@@ -665,9 +646,8 @@ class TestListUndoItem(UnittestTools, unittest.TestCase):
 
 
 class TestUndoHistory(UnittestTools, unittest.TestCase):
-
     def _populate_history(self, history):
-        """ Add some simple hostory items. """
+        """Add some simple hostory items."""
         self._example = SimpleExample()
         history.add(
             UndoItem(
@@ -908,7 +888,9 @@ class TestUndoHistory(UnittestTools, unittest.TestCase):
 
         with self.assertTraitDoesNotChange(history, 'undoable'):
             with self.assertTraitChanges(history, 'redoable', count=1):
-                with self.assertTraitChanges(self._example, 'anytrait', count=1):  # noqa: E501
+                with self.assertTraitChanges(
+                    self._example, 'anytrait', count=1
+                ):  # noqa: E501
                     history.undo()
 
         self.assertEqual(history.now, 2)
@@ -923,7 +905,9 @@ class TestUndoHistory(UnittestTools, unittest.TestCase):
 
         with self.assertTraitDoesNotChange(history, 'redoable'):
             with self.assertTraitChanges(history, 'undoable', count=1):
-                with self.assertTraitChanges(self._example, 'anytrait', count=1):  # noqa: E501
+                with self.assertTraitChanges(
+                    self._example, 'anytrait', count=1
+                ):  # noqa: E501
                     history.undo()
 
         self.assertEqual(history.now, 0)
@@ -937,7 +921,9 @@ class TestUndoHistory(UnittestTools, unittest.TestCase):
 
         with self.assertTraitDoesNotChange(history, 'redoable'):
             with self.assertTraitDoesNotChange(history, 'undoable'):
-                with self.assertTraitChanges(self._example, 'anytrait', count=1):  # noqa: E501
+                with self.assertTraitChanges(
+                    self._example, 'anytrait', count=1
+                ):  # noqa: E501
                     history.undo()
 
         self.assertEqual(history.now, 1)
@@ -951,7 +937,9 @@ class TestUndoHistory(UnittestTools, unittest.TestCase):
 
         with self.assertTraitChanges(history, 'redoable', count=1):
             with self.assertTraitDoesNotChange(history, 'undoable'):
-                with self.assertTraitChanges(self._example, 'anytrait', count=1):  # noqa: E501
+                with self.assertTraitChanges(
+                    self._example, 'anytrait', count=1
+                ):  # noqa: E501
                     history.redo()
 
         self.assertEqual(history.now, 3)
@@ -966,7 +954,9 @@ class TestUndoHistory(UnittestTools, unittest.TestCase):
 
         with self.assertTraitDoesNotChange(history, 'redoable'):
             with self.assertTraitDoesNotChange(history, 'undoable'):
-                with self.assertTraitChanges(self._example, 'anytrait', count=1):  # noqa: E501
+                with self.assertTraitChanges(
+                    self._example, 'anytrait', count=1
+                ):  # noqa: E501
                     history.redo()
 
         self.assertEqual(history.now, 2)
@@ -982,7 +972,9 @@ class TestUndoHistory(UnittestTools, unittest.TestCase):
 
         with self.assertTraitDoesNotChange(history, 'redoable'):
             with self.assertTraitChanges(history, 'undoable', count=1):
-                with self.assertTraitChanges(self._example, 'anytrait', count=1):  # noqa: E501
+                with self.assertTraitChanges(
+                    self._example, 'anytrait', count=1
+                ):  # noqa: E501
                     history.redo()
 
         self.assertEqual(history.now, 1)
@@ -995,7 +987,9 @@ class TestUndoHistory(UnittestTools, unittest.TestCase):
 
         with self.assertTraitChanges(history, 'redoable', count=2):
             with self.assertTraitChanges(history, 'undoable', count=1):
-                with self.assertTraitChanges(self._example, 'anytrait', count=3):  # noqa: E501
+                with self.assertTraitChanges(
+                    self._example, 'anytrait', count=3
+                ):  # noqa: E501
                     history.revert()
 
         self.assertEqual(history.now, 0)
@@ -1010,7 +1004,9 @@ class TestUndoHistory(UnittestTools, unittest.TestCase):
 
         with self.assertTraitChanges(history, 'redoable', count=1):
             with self.assertTraitChanges(history, 'undoable', count=1):
-                with self.assertTraitChanges(self._example, 'anytrait', count=1):  # noqa: E501
+                with self.assertTraitChanges(
+                    self._example, 'anytrait', count=1
+                ):  # noqa: E501
                     history.revert()
 
         self.assertEqual(history.now, 0)
@@ -1144,7 +1140,6 @@ class TestUndoHistory(UnittestTools, unittest.TestCase):
 
 @unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
 class TestEditorUndo(BaseTestMixin, GuiTestAssistant, unittest.TestCase):
-
     def setUp(self):
         BaseTestMixin.setUp(self)
         GuiTestAssistant.setUp(self)
@@ -1153,8 +1148,9 @@ class TestEditorUndo(BaseTestMixin, GuiTestAssistant, unittest.TestCase):
         GuiTestAssistant.tearDown(self)
         BaseTestMixin.tearDown(self)
 
-    def check_history(self, editor, expected_history_now,
-                      expected_history_length):
+    def check_history(
+        self, editor, expected_history_now, expected_history_length
+    ):
         # XXX this is testing private state
         return (
             editor.ui.history.now == expected_history_now
@@ -1185,21 +1181,31 @@ class TestEditorUndo(BaseTestMixin, GuiTestAssistant, unittest.TestCase):
         self.undo(editor)
 
         # Expect 2 items in history and pointer at first item
-        self.assertEventuallyTrue(editor, "ui",
-                                  functools.partial(self.check_history,
-                                                    expected_history_now=1,
-                                                    expected_history_length=2),
-                                  timeout=5.0)
+        self.assertEventuallyTrue(
+            editor,
+            "ui",
+            functools.partial(
+                self.check_history,
+                expected_history_now=1,
+                expected_history_length=2,
+            ),
+            timeout=5.0,
+        )
 
         # Perform a REDO
         self.redo(editor)
 
         # Expect 2 items in history and pointer at second item
-        self.assertEventuallyTrue(editor, "ui",
-                                  functools.partial(self.check_history,
-                                                    expected_history_now=2,
-                                                    expected_history_length=2),
-                                  timeout=5.0)
+        self.assertEventuallyTrue(
+            editor,
+            "ui",
+            functools.partial(
+                self.check_history,
+                expected_history_now=2,
+                expected_history_length=2,
+            ),
+            timeout=5.0,
+        )
 
         # Enter 'three'
         with editor.updating_value():
@@ -1209,11 +1215,16 @@ class TestEditorUndo(BaseTestMixin, GuiTestAssistant, unittest.TestCase):
         self.undo(editor)
 
         # Expect 3 items in history and pointer at second item
-        self.assertEventuallyTrue(editor, "ui",
-                                  functools.partial(self.check_history,
-                                                    expected_history_now=2,
-                                                    expected_history_length=3),
-                                  timeout=5.0)
+        self.assertEventuallyTrue(
+            editor,
+            "ui",
+            functools.partial(
+                self.check_history,
+                expected_history_now=2,
+                expected_history_length=3,
+            ),
+            timeout=5.0,
+        )
 
         # Enter 'four'
         with editor.updating_value():
@@ -1223,11 +1234,16 @@ class TestEditorUndo(BaseTestMixin, GuiTestAssistant, unittest.TestCase):
         # Expect 3 items in history and pointer at second item
         # Note: Modifying the history after an UNDO, clears the future,
         # hence, we expect 3 items in the history, not 4
-        self.assertEventuallyTrue(editor, "ui",
-                                  functools.partial(self.check_history,
-                                                    expected_history_now=3,
-                                                    expected_history_length=3),
-                                  timeout=5.0)
+        self.assertEventuallyTrue(
+            editor,
+            "ui",
+            functools.partial(
+                self.check_history,
+                expected_history_now=3,
+                expected_history_length=3,
+            ),
+            timeout=5.0,
+        )
 
         # The following sequence after modifying the history had caused
         # the application to hang, verify it.
@@ -1238,8 +1254,13 @@ class TestEditorUndo(BaseTestMixin, GuiTestAssistant, unittest.TestCase):
         self.redo(editor)
 
         # Expect 3 items in history and pointer at second item
-        self.assertEventuallyTrue(editor, "ui",
-                                  functools.partial(self.check_history,
-                                                    expected_history_now=2,
-                                                    expected_history_length=3),
-                                  timeout=5.0)
+        self.assertEventuallyTrue(
+            editor,
+            "ui",
+            functools.partial(
+                self.check_history,
+                expected_history_now=2,
+                expected_history_length=3,
+            ),
+            timeout=5.0,
+        )
