@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -22,8 +22,7 @@ from .editor import Editor
 
 
 class SimpleEditor(BaseSimpleEditor, Editor):
-    """ Simple style of editor for arrays.
-    """
+    """Simple style of editor for arrays."""
 
     # FIXME: This class has been re-defined here simply so it inherits from the
     # wx Editor class.
