@@ -1,4 +1,13 @@
-from __future__ import absolute_import
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
+
 import wx
 
 from traits.api import Instance, Int, Str
@@ -7,10 +16,8 @@ from pyface.ui.wx.progress_dialog import ProgressDialog
 
 
 class _ProgressDialog(ProgressDialog):
-
     def close(self):
-        """ Overwritten to disable closing.
-        """
+        """Overwritten to disable closing."""
         pass
 
 
@@ -23,28 +30,28 @@ class SimpleEditor(Editor):
     progress = Instance(ProgressDialog)
 
     # The message to be displayed along side the progress guage
-    message = Str
+    message = Str()
 
     # The starting value
-    min = Int
+    min = Int()
 
     # The ending value
-    max = Int
+    max = Int()
 
-    #-- Editor interface ------------------------------------------------------
+    # -- Editor interface ------------------------------------------------------
 
     def init(self, parent):
-        """ Finishes initializing the editor by creating the underlying toolkit
-            widget.
+        """Finishes initializing the editor by creating the underlying toolkit
+        widget.
         """
         self.control = self.create_control(parent)
         factory = self.factory
         self.min = factory.min
         self.max = factory.max
         self.message = factory.message
-        self.sync_value(factory.min_name, 'min', 'from')
-        self.sync_value(factory.max_name, 'max', 'from')
-        self.sync_value(factory.message_name, 'message', 'from')
+        self.sync_value(factory.min_name, "min", "from")
+        self.sync_value(factory.max_name, "max", "from")
+        self.sync_value(factory.message_name, "message", "from")
         self.set_tooltip()
 
     def create_control(self, parent):
@@ -52,13 +59,15 @@ class SimpleEditor(Editor):
         Finishes initializing the editor by creating the underlying widget.
         """
 
-        self.progress = ProgressDialog(title=self.factory.title,
-                                       message=self.factory.message,
-                                       min=self.factory.min,
-                                       max=self.factory.max,
-                                       can_cancel=self.factory.can_cancel,
-                                       show_time=self.factory.show_time,
-                                       show_percent=self.factory.show_percent)
+        self.progress = ProgressDialog(
+            title=self.factory.title,
+            message=self.factory.message,
+            min=self.factory.min,
+            max=self.factory.max,
+            can_cancel=self.factory.can_cancel,
+            show_time=self.factory.show_time,
+            show_percent=self.factory.show_percent,
+        )
 
         panel = wx.Panel(parent, -1)
 
@@ -91,9 +100,7 @@ class SimpleEditor(Editor):
         self.progress.min = self.min
         self.progress.max = self.max
         self.progress.change_message(self.message)
-        if self.value:
-            self.progress.update(self.value)
-        return
+        self.progress.update(self.value)
 
     def _min_changed(self):
         self.update_editor()
