@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -33,10 +33,10 @@ from traitsui.wx.color_trait import standard_colors, w3c_color_database
 
 
 def range_check(value):
-    """ Checks that *value* can be converted to a value in the range 0.0 to 1.0.
+    """Checks that *value* can be converted to a value in the range 0.0 to 1.0.
 
-        If so, it returns the floating point value; otherwise, it raises a
-        TraitError.
+    If so, it returns the floating point value; otherwise, it raises a
+    TraitError.
     """
     value = float(value)
     if 0.0 <= value <= 1.0:
@@ -45,8 +45,8 @@ def range_check(value):
 
 
 def convert_to_color(object, name, value):
-    """ Converts a tuple or an integer to an RGB color value, or raises a
-        TraitError if that is not possible.
+    """Converts a tuple or an integer to an RGB color value, or raises a
+    TraitError if that is not possible.
     """
     if (type(value) in SequenceTypes) and (len(value) == 3):
         return (
@@ -57,7 +57,8 @@ def convert_to_color(object, name, value):
     if isinstance(value, int):
         num = int(value)
         return (
-            (num // 0x10000) / 255.0, ((num // 0x100) & 0xFF) / 255.0,
+            (num // 0x10000) / 255.0,
+            ((num // 0x100) & 0xFF) / 255.0,
             (num & 0xFF) / 255.0,
         )
     if isinstance(value, wx.Colour):
