@@ -1,4 +1,4 @@
-# (C) Copyright 2004-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2004-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -36,8 +36,7 @@ KEEP_ALIVE_UIS = set()
 
 
 def on_ui_destroyed(object, name, old, destroyed):
-    """ Remove the UI object from KEEP_ALIVE_UIS.
-    """
+    """Remove the UI object from KEEP_ALIVE_UIS."""
     assert name == "destroyed"
     if destroyed:
         assert object in KEEP_ALIVE_UIS
@@ -51,7 +50,7 @@ def on_ui_destroyed(object, name, old, destroyed):
 
 
 def view_application(context, view, kind, handler, id, scrollable, args):
-    """ Creates a stand-alone wx Application to display a specified traits UI
+    """Creates a stand-alone wx Application to display a specified traits UI
         View.
 
     Parameters
@@ -108,12 +107,10 @@ def view_application(context, view, kind, handler, id, scrollable, args):
 
 
 class ViewApplication(wx.App):
-    """ Modal window that contains a stand-alone application.
-    """
+    """Modal window that contains a stand-alone application."""
 
     def __init__(self, context, view, kind, handler, id, scrollable, args):
-        """ Initializes the object.
-        """
+        """Initializes the object."""
         self.context = context
         self.view = view
         self.kind = kind
@@ -134,8 +131,7 @@ class ViewApplication(wx.App):
             logger.exception("Event loop failed to close cleanly:")
 
     def OnInit(self):
-        """ Handles application initialization.
-        """
+        """Handles application initialization."""
         self.ui = self.view.ui(
             self.context,
             kind=self.kind,
